convert

package module
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 23, 2022 License: MIT Imports: 1 Imported by: 34

README

Convert

Go Version Go Report Card Build Status GoDoc

Golang conversion library

This library converts, at the moment ints to big endian bytes It is used in both twofactor and cryptoengine libraries

Documentation

Overview

Package used to round float to the nearest integet

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Round

func Round(n float64) uint64

Helper function which rounds the float to the nearest integet

Types

This section is empty.

Directories

Path Synopsis
Package used to convert intergers to byte arrays in big endian
Package used to convert intergers to byte arrays in big endian
Package used to convert intergers to byte arrays in small endian
Package used to convert intergers to byte arrays in small endian

Jump to